@@ -1,5 +1,5 @@
 package Template::Liquid::Tag::Break;
-our $VERSION = '1.0.19';
+our $VERSION = '1.0.20';
 use strict;
 use warnings;
 require Template::Liquid::Error;
@@ -50,6 +50,12 @@ sub render {
 
 =encoding UTF-8
 
+=begin stopwords
+
+Ltke jadedPixel
+
+=end stopwords
+
 =head1 NAME
 
 Template::Liquid::Tag::Break - For-block killing construct
@@ -84,7 +90,7 @@ The original Liquid template system was developed by jadedPixel
 
 =head1 License and Legal
 
-Copyright (C) 2009-2012 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
+Copyright (C) 2009-2022 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
 
 This program is free software; you can redistribute it and/or modify it under
 the terms of The Artistic License 2.0.  See the F<LICENSE> file included with
