@@ -1,5 +1,5 @@
 package Template::Liquid::Tag::Decrement;
-our $VERSION = '1.0.19';
+our $VERSION = '1.0.20';
 use strict;
 use warnings;
 require Template::Liquid::Error;
@@ -16,6 +16,12 @@ sub _me        {'decrement'}
 
 =encoding UTF-8
 
+=begin stopwords
+
+Ltke jadedPixel
+
+=end stopwords
+
 =head1 NAME
 
 Template::Liquid::Tag::Decrement - Document-level Persistant Number
@@ -55,7 +61,7 @@ The original Liquid template system was developed by jadedPixel
 
 =head1 License and Legal
 
-Copyright (C) 2009-2012 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
+Copyright (C) 2009-2022 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
 
 This program is free software; you can redistribute it and/or modify it under
 the terms of The Artistic License 2.0.  See the F<LICENSE> file included with
