@@ -2,7 +2,7 @@ package Template::Liquid::Utility;
 use experimental 'signatures';
 use strict;
 use warnings;
-our $VERSION         = '1.0.19';
+our $VERSION         = '1.0.20';
 our $FilterSeparator = qr[\s*\|\s*]o;
 my $ArgumentSeparator = qr[,]o;
 our $FilterArgumentSeparator    = qr[\s*:\s*]o;
@@ -50,7 +50,7 @@ our $VarMatch = qr[^${Template::Liquid::Utility::VariableStart} # {{
                 $]sox;
 
 sub tokenize {
-    map { $_ ? $_ : () } split $TemplateParser, shift || '';
+    map { defined $_ ? $_ : () } split $TemplateParser, shift || '';
 }
 1;
 
@@ -58,6 +58,12 @@ sub tokenize {
 
 =encoding UTF-8
 
+=begin stopwords
+
+Ltke jadedPixel
+
+=end stopwords
+
 =head1 NAME
 
 Template::Liquid::Utility - Utility stuff. Watch your step.
@@ -82,7 +88,7 @@ The original Liquid template system was developed by jadedPixel
 
 =head1 License and Legal
 
-Copyright (C) 2009-2012 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
+Copyright (C) 2009-2022 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
 
 This program is free software; you can redistribute it and/or modify it under
 the terms of The Artistic License 2.0.  See the F<LICENSE> file included with
